@@ -1,7 +1,7 @@
 import logging
 
 from django.db import connections
-from django.db.models import Model, DateTimeField, Manager, TextField, GenericIPAddressField
+from django.db.models import Model, DateTimeField, Manager, TextField, GenericIPAddressField, BigAutoField
 from django.utils import timezone
 
 from isc_common.auth.models.user import User
@@ -77,6 +77,7 @@ class HistoryManager(Manager):
 
 
 class History(Model):
+    id = BigAutoField(primary_key=True, verbose_name="Идентификатор")
     date = DateTimeField(db_index=True, default=timezone.now)
     method = CodeField()
     path = CodeStrictField()
