@@ -25,9 +25,6 @@ class User(AbstractUser):
     def __str__(self):
         return f"id: {self.id}, username: {self.username}, full_name: ({self.first_name} {self.middle_name} {self.last_name})"
 
-    def save(self, *args, **kwargs):
-        super().save(*args, **kwargs)
-
     objects = UserManager()
 
     class Meta:
