@@ -15,6 +15,7 @@ from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_tree_grid_manager import CommonTreeGridManager
 from isc_common.models.audit import AuditQuerySet
 from isc_common.models.base_ref import Hierarcy
+from isc_common.models.tree_audit import TreeAuditModelManager
 from isc_common.number import DelProps
 from tracker.models.messages_importance import Messages_importance
 from tracker.models.messages_state import Messages_state
@@ -244,13 +245,14 @@ class MessagesManager(CommonTreeGridManager):
 
         old_to_whom_id = old_data.get('to_whom_id')
         to_whom_id = data.get('to_whom_id')
-        message_text = old_data.get('message').replace('<pre>', '').replace('</pre>', '')
+        # message_text = data.get('message').replace('<pre>', '').replace('</pre>', '')
+        message_text = data.get('message')
 
         if old_to_whom_id != to_whom_id:
             setAttr(data_clone, 'user_id', request.user_id)
             setAttr(data_clone, 'parent_id', id)
             setAttr(data_clone, 'guid', uuid.uuid4())
-            setAttr(data, 'message', message_text)
+            # setAttr(data, 'message', message_text)
 
             with transaction.atomic():
                 res = super().create(**data_clone)
@@ -359,6 +361,8 @@ class Messages(Hierarcy):
         return f'id: {self.id}, guid: {str(self.guid).upper()}, message: {self.message}, user: [{self.user}], theme: [{self.theme}], state: [{self.state}]'
 
     objects = MessagesManager()
+    objects1 = TreeAuditModelManager()
+
 
     class Meta:
         verbose_name = 'Сообщения'
