@@ -27,13 +27,13 @@ class Messages_admin_viewQuerySet(MessagesQuerySet):
 
 class Messages_admin_viewManager(MessagesManager):
 
-    @staticmethod
-    def getRecord(record, enabled=None):
+    @classmethod
+    def getRecord(cls, record, enabled=None):
         res = {
             'date_create': record.lastmodified,
             'deliting': record.deliting,
             'editing': record.editing,
-            'enabled': record.state.code != 'closed' and record.state.code != 'readed' or enabled is True,
+            'enabled': record.state.code != 'closed' and record.state.code != 'readed' or enabled == True,
             'guid': str(record.guid).upper() if record.guid else None,
             'id': record.id,
             'importance__code': record.importance.code if record.importance else None,
