@@ -1,3 +1,4 @@
+from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException, JsonWSResponseWithException, JsonWSPostResponseWithException
 from isc_common.http.RPCResponse import RPCResponseConstant
 from isc_common.http.response import JsonResponse
@@ -24,14 +25,22 @@ def Messages_Fetch(request):
 
 @JsonResponseWithException(printing=False)
 def Messages_Fetch4Chat(request):
+    guids=[]
+    res=[]
+    data = Messages.objects. \
+        get_range_rows1(
+        request=request,
+        function=MessagesManager.getRecord
+    )
+    for item in data:
+        if not item.get('guid') in guids:
+            res.append(item)
+            guids.append(item.get('guid'))
+
     return JsonResponse(
         DSResponse(
             request=request,
-            data=Messages.objects.
-                get_range_rows1(
-                request=request,
-                function=MessagesManager.getRecord
-            ),
+            data=res,
             status=RPCResponseConstant.statusSuccess).response)
 
 
